==> apache-ignite-2.5.0-src.zip: apache-ignite-2.5.0-src/modules/web-console/frontend/app/data/i18n.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
    '/agent/start': 'Agent start',
    '/agent/download': 'Agent download',
    'base.configuration.overview': 'Cluster configurations',
    '/configuration/overview': 'Cluster configurations',
    'base.configuration.edit.basic': 'Basic cluster configuration edit',
    '/configuration/new': 'Сluster configuration create',
    '/configuration/new/basic': 'Basic cluster configuration create',
    '/configuration/new/advanced/cluster': 'Advanced cluster configuration create',
    'base.configuration.edit.advanced.cluster': 'Advanced cluster configuration edit',
    'base.configuration.edit.advanced.caches': 'Advanced cluster caches',
    'base.configuration.edit.advanced.caches.cache': 'Advanced cluster cache edit',
    'base.configuration.edit.advanced.models': 'Advanced cluster models',
    'base.configuration.edit.advanced.models.model': 'Advanced cluster model edit',
    'base.configuration.edit.advanced.igfs': 'Advanced cluster IGFSs',
    'base.configuration.edit.advanced.igfs.igfs': 'Advanced cluster IGFS edit',
    '/configuration/download': 'Download project',
    '/demo/resume': 'Demo resume',
    '/demo/reset': 'Demo reset',
    '/queries/execute': 'Query execute',
    '/queries/explain': 'Query explain',
    '/queries/scan': 'Scan',
    '/queries/add/query': 'Add query',
    '/queries/add/scan': 'Add scan',
    '/queries/demo': 'SQL demo',
    '/queries/notebook/': 'Query notebook',
    '/settings/profile': 'User profile',
    '/settings/admin': 'Admin panel',
    '/logout': 'Logout'
};

==> apache-ignite-2.7.0-src.zip: apache-ignite-2.7.0-src/modules/web-console/frontend/app/data/i18n.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
    '/agent/start': 'Agent start',
    '/agent/download': 'Agent download',
    'base.configuration.overview': 'Cluster configurations',
    '/configuration/overview': 'Cluster configurations',
    'base.configuration.edit.basic': 'Basic cluster configuration edit',
    '/configuration/new': 'Cluster configuration create',
    '/configuration/new/basic': 'Basic cluster configuration create',
    '/configuration/new/advanced/cluster': 'Advanced cluster configuration create',
    'base.configuration.edit.advanced.cluster': 'Advanced cluster configuration edit',
    'base.configuration.edit.advanced.caches': 'Advanced cluster caches',
    'base.configuration.edit.advanced.caches.cache': 'Advanced cluster cache edit',
    'base.configuration.edit.advanced.models': 'Advanced cluster models',
    'base.configuration.edit.advanced.models.model': 'Advanced cluster model edit',
    'base.configuration.edit.advanced.igfs': 'Advanced cluster IGFSs',
    'base.configuration.edit.advanced.igfs.igfs': 'Advanced cluster IGFS edit',
    '/configuration/download': 'Download project',
    '/demo/resume': 'Demo resume',
    '/demo/reset': 'Demo reset',
    '/queries/execute': 'Query execute',
    '/queries/explain': 'Query explain',
    '/queries/scan': 'Scan',
    '/queries/add/query': 'Add query',
    '/queries/add/scan': 'Add scan',
    '/queries/demo': 'SQL demo',
    '/queries/notebook/': 'Query notebook',
    '/settings/profile': 'User profile',
    '/settings/admin': 'Admin panel',
    '/logout': 'Logout'
};
